@@ -1,4 +1,13 @@
-(* $Id: kaimono.ml,v 1.8 2001/09/06 08:47:55 garrigue Exp $ *)
+(**************************************************************************)
+(*    Lablgtk - Examples                                                  *)
+(*                                                                        *)
+(*    There is no specific licensing policy, but you may freely           *)
+(*    take inspiration from the code, and copy parts of it in your        *)
+(*    application.                                                        *)
+(*                                                                        *)
+(**************************************************************************)
+
+(* $Id: kaimono.ml 1347 2007-06-20 07:40:34Z guesdon $ *)
 
 open StdLabels
 open GMain
@@ -9,7 +18,7 @@ let file_dialog ~title ~callback ?filename () =
   sel#cancel_button#connect#clicked ~callback:sel#destroy;
   sel#ok_button#connect#clicked ~callback:
     begin fun () ->
-      let name = sel#get_filename in
+      let name = sel#filename in
       sel#destroy ();
       callback name
     end;
@@ -47,8 +56,9 @@ let add_entry () =
 
 let _ =
   List.iter2 ["Number";"Name";"Count";"Price"] [40;200;40;60] ~f:
-    begin fun text width ->
-      ignore (GButton.button ~label:text ~width ~packing:add_to_table ())
+    begin fun label width ->
+      let b = GButton.button ~label ~packing:add_to_table () in
+      b#misc#set_size_request ~width ()
     end;
   for i = 1 to 9 do add_entry () done
 
