@@ -20,7 +20,7 @@
 (*                                                                        *)
 (**************************************************************************)
 
-(* $Id: gButton.mli 1347 2007-06-20 07:40:34Z guesdon $ *)
+(* $Id: gButton.mli 1515 2010-06-08 08:50:23Z garrigue $ *)
 
 open Gtk
 open GObj
@@ -52,6 +52,10 @@ class button_skel : 'a obj ->
     method image : GObj.widget             (** @since GTK 2.6 *)
     method set_image : GObj.widget -> unit (** @since GTK 2.6 *)
     method unset_image : unit -> unit      (** @since GTK 2.6 *)
+    method image_position : GtkEnums.position_type  (** @since GTK 2.10 *)
+    method set_image_position : GtkEnums.position_type -> unit 
+	(** @since GTK 2.10 *)
+ 
     method set_xalign : float -> unit  (** @since GTK 2.4 *)
     method xalign     : float          (** @since GTK 2.4 *)
     method set_yalign : float -> unit  (** @since GTK 2.4 *)
@@ -353,9 +357,10 @@ end
 (** @gtkdoc gtk GtkToolItem 
     @since GTK 2.4 *)
 class tool_item : 
-  [> Gtk.tool_item] obj ->
+  ([> Gtk.tool_item] as 'a) obj ->
   object
     inherit tool_item_skel
+    val obj : 'a obj
     method connect : GContainer.container_signals
   end
 
@@ -419,9 +424,10 @@ class tool_button_skel :
 (** @gtkdoc gtk GtkToolButton
     @since GTK 2.4 *)
 class tool_button : 
-  [> Gtk.tool_button] obj ->
+  ([> Gtk.tool_button] as 'a) obj ->
   object
     inherit tool_button_skel
+    val obj : 'a obj
     method connect : tool_button_signals
   end
 
