@@ -1,10 +1,33 @@
-/* $Id: wrappers.h,v 1.61 2004/11/10 19:54:03 oandrieu Exp $ */
+/**************************************************************************/
+/*                Lablgtk                                                 */
+/*                                                                        */
+/*    This program is free software; you can redistribute it              */
+/*    and/or modify it under the terms of the GNU Library General         */
+/*    Public License as published by the Free Software Foundation         */
+/*    version 2, with the exception described in file COPYING which       */
+/*    comes with the library.                                             */
+/*                                                                        */
+/*    This program is distributed in the hope that it will be useful,     */
+/*    but WITHOUT ANY WARRANTY; without even the implied warranty of      */
+/*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the       */
+/*    GNU Library General Public License for more details.                */
+/*                                                                        */
+/*    You should have received a copy of the GNU Library General          */
+/*    Public License along with this program; if not, write to the        */
+/*    Free Software Foundation, Inc., 59 Temple Place, Suite 330,         */
+/*    Boston, MA 02111-1307  USA                                          */
+/*                                                                        */
+/*                                                                        */
+/**************************************************************************/
+
+/* $Id: wrappers.h 1467 2009-08-29 21:28:12Z ben_99_9 $ */
 
 #ifndef _wrappers_
 #define _wrappers_
 
 /* Yell if a caml callback raised an exception */
 #define CAML_EXN_LOG(name) g_critical("%s: callback raised an exception", name)
+#define CAML_EXN_LOG_VERBOSE(name,exn) g_critical("%s: callback raised exception %s", name, format_caml_exception(Extract_exception(exn)))
 
 #include <caml/misc.h>
 #include <caml/mlvalues.h>
@@ -12,23 +35,27 @@
 #include <caml/custom.h>
 CAMLextern char *young_start, *young_end; /* from minor_gc.h */
 
-value copy_memblock_indirected (void *src, asize_t size);
+CAMLexport value copy_memblock_indirected (void *src, asize_t size);
 value alloc_memblock_indirected (asize_t size);
 CAMLprim value ml_some (value);
 value ml_cons (value, value);
-void ml_raise_null_pointer (void) Noreturn;
-value Val_pointer (void *);
+CAMLexport void ml_raise_null_pointer (void) Noreturn;
+CAMLexport value Val_pointer (void *);
 CAMLprim value copy_string_check (const char*);
 value copy_string_or_null (const char *);
 
+value string_list_of_strv (const char * const *v);
+value string_list_of_strv2 (char **v);
+char ** strv_of_string_list (value list);
+
 CAMLprim value *ml_global_root_new (value v);
-void ml_global_root_destroy (void *data);
+CAMLexport void ml_global_root_destroy (void *data);
 
 /* enums <-> polymorphic variants */
 typedef struct { value key; int data; } lookup_info;
-value ml_lookup_from_c (const lookup_info table[], int data);
-int ml_lookup_to_c (const lookup_info table[], value key);
-value ml_lookup_flags_getter (const lookup_info table[], int data);
+CAMLexport value ml_lookup_from_c (const lookup_info table[], int data);
+CAMLexport int ml_lookup_to_c (const lookup_info table[], value key);
+CAMLexport value ml_lookup_flags_getter (const lookup_info table[], int data);
 
 /* Compatibility */
 #include <gtk/gtkversion.h>
@@ -38,15 +65,41 @@ value ml_lookup_flags_getter (const lookup_info table[], int data);
 #if GTK_CHECK_VERSION(2,4,0) && !defined(DISABLE_GTK24)
 #define HASGTK24
 #endif
+#if GTK_CHECK_VERSION(2,5,3) && !defined(DISABLE_GTK26)
+#define HASGTK26
+#endif
+#if GTK_CHECK_VERSION(2,8,0) && !defined(DISABLE_GTK28)
+#define HASGTK28
+#endif
+#if GTK_CHECK_VERSION(2,10,0) && !defined(DISABLE_GTK210)
+#define HASGTK210
+#endif
+#if GTK_CHECK_VERSION(2,12,0) && !defined(DISABLE_GTK212)
+#define HASGTK212
+#endif
 
 /* Wrapper generators */
 
-#define Unsupported(cname) \
+#define Unsupported_22(cname) \
 CAMLprim value ml_##cname () \
-{ failwith(#cname " unsupported in Gtk 2.x < 2.2"); return Val_unit; }
+{ failwith(#cname " unsupported in Gtk 2.x < 2.2"); }
+#define Unsupported Unsupported_22
 #define Unsupported_24(cname) \
 CAMLprim value ml_##cname () \
-{ failwith(#cname " unsupported in Gtk 2.x < 2.4"); return Val_unit; }
+{ failwith(#cname " unsupported in Gtk 2.x < 2.4"); }
+#define Unsupported_26(cname) \
+CAMLprim value ml_##cname () \
+{ failwith(#cname " unsupported in Gtk 2.x < 2.6"); }
+#define Unsupported_28(cname) \
+CAMLprim value ml_##cname () \
+{ failwith(#cname " unsupported in Gtk 2.x < 2.8"); }
+
+#define Unsupported_210(cname) \
+CAMLprim value ml_##cname () \
+{ failwith(#cname " unsupported in Gtk 2.x < 2.10"); }
+#define Unsupported_212(cname) \
+CAMLprim value ml_##cname () \
+{ failwith(#cname " unsupported in Gtk 2.x < 2.12"); }
 
 #define ID(x) (x)
 
@@ -231,7 +284,7 @@ static void ml_final_##type (value val) \
 static struct custom_operations ml_custom_##type = \
 { #type"/2.0/", ml_final_##type, custom_compare_default, \
   custom_hash_default, custom_serialize_default, custom_deserialize_default };\
-value Val_##type (type *p) \
+CAMLprim value Val_##type (type *p) \
 { value ret; if (!p) ml_raise_null_pointer(); \
   ret = alloc_custom (&ml_custom_##type, sizeof(value), adv, 1000); \
   initialize (&Field(ret,1), (value) p); init(p); return ret; }
@@ -242,7 +295,7 @@ static void ml_final_##type##ext (value val) \
 static struct custom_operations ml_custom_##type##ext = \
 { #type#ext"/2.0/", ml_final_##type##ext, custom_compare_default, \
   custom_hash_default, custom_serialize_default, custom_deserialize_default };\
-value Val_##type##ext (type *p) \
+CAMLprim value Val_##type##ext (type *p) \
 { value ret; if (!p) ml_raise_null_pointer(); \
   ret = alloc_custom (&ml_custom_##type##ext, sizeof(value), adv, 1000); \
   initialize (&Field(ret,1), (value) p); init(p); return ret; }
@@ -255,7 +308,7 @@ static int ml_comp_##type(value v1, value v2) \
 static struct custom_operations ml_custom_##type = \
 { #type"/2.0/", ml_final_##type, ml_comp_##type, \
   custom_hash_default, custom_serialize_default, custom_deserialize_default };\
-value Val_##type (type *p) \
+CAMLprim value Val_##type (type *p) \
 { value ret; if (!p) ml_raise_null_pointer(); \
   ret = alloc_custom (&ml_custom_##type, sizeof(value), adv, 1000); \
   initialize (&Field(ret,1), (value) p); init(p); return ret; }
@@ -263,7 +316,7 @@ value Val_##type (type *p) \
 #define Pointer_val(val) ((void*)Field(val,1))
 #define Store_pointer(val,p) (Field(val,1)=Val_bp(p))
 #define MLPointer_val(val) \
-        (Field(val,1) == 2 ? &Field(val,2) : (void*)Field(val,1))
+        ((int)Field(val,1) == 2 ? &Field(val,2) : (void*)Field(val,1))
 
 #define Val_addr(ptr) (1+(value)ptr)
 #define Addr_val(val) ((void*)(val-1))
@@ -289,17 +342,17 @@ CAMLprim value ml_##name##_##field (value val, value index, value new) \
 
 /* ML value is [flag list] */
 #define Make_Flags_val(conv) \
-int Flags_##conv (value list) \
+CAMLprim int Flags_##conv (value list) \
 { int flags = 0L; \
-  while Is_block(list) { flags |= conv(Field(list,0)); list = Field(list,1); }\
+  while(Is_block(list)){ flags |= conv(Field(list,0)); list = Field(list,1); }\
   return flags; }
 
 /* ML value is [flag list option] */
 #define Make_OptFlags_val(conv) \
-int OptFlags_##conv (value list) \
+CAMLprim int OptFlags_##conv (value list) \
 { int flags = 0L; \
-  if Is_block(list) list = Field(list,0); \
-  while Is_block(list) { flags |= conv(Field(list,0)); list = Field(list,1); }\
+  if (Is_block(list)) list = Field(list,0); \
+  while(Is_block(list)){ flags |= conv(Field(list,0)); list = Field(list,1); }\
   return flags; }
 
 #define Val_copy(val) copy_memblock_indirected (&val, sizeof(val))
